##################################################################################################################
#
# Fertility progression in Gernamy : An application using non-parametric cure survival models
# Add here the reference!
#
# Code writen by V.Bremhorst (Universite catholique de Louvain - Belgium)
# Joint work with : * Michaela Kreyenfeld (Hertie School of Governance Berlin - Max Planck Insitute for 
#									      Demographic Research (Rostock)
#                   * Philippe Lambert (Universite de Liege and Universite catholique de Louvain (Beligum) 
#
# Contact : vincent.bremhorst@uclouvain.be  or vbremhorst@gmail.com 
#
#
#
#		   ************************************
#  	   * Main file : Second birth example *
#		   ************************************
#
#
####################################################################################################################

# Clean the workspace
remove(list = ls())

# Define the working directory
# Example : setwd("/home/my_name/Desktop/my_work")

# Load all needed packages
# N.B. Packages "survival", "coda" and "compiler" need to be installed on your computer.
# For the installation : install.packages("package_name")
#dyn.load("Functions/Bremhorstetal2016_FortranRoutines.so") # Contain the Fortran routines needed for the generation of the posterior samples.
dyn.load("Functions/Bremhorstetal2016_FortranRoutines.dll") # Contain the Fortran routines needed for the generation of the posterior samples.

library(coda)
library(compiler)
library(survival)

# Load all needed R functions
source("Functions/Bremhorstetal2016_mainFunction.R")
source("Functions/Bremhorstetal2016_bayesianEstimation.R")
source("Functions/Bremhorstetal2016_convergenceIssues.R")
source("Functions/Bremhorstetal2016_logpost.R")
source("Functions/Bremhorstetal2016_numericalResults.R") 
source("Functions/Bremhorstetal2016_hazardFunctions.R")
source("Functions/Bremhorstetal2016_hazardGraphs.R")
source("Functions/Bremhorstetal2016_CredIntervalFunctions.R")
source("Functions/Bremhorstetal2016_PosteriorProbabilities.R")

# read the data
data <- read.table(file = "SecondBirthBaseline.txt", header = TRUE, sep = "\t")

# Define the reference category of the categorical independent variables
data$EDU02 <- relevel(data$EDU02, ref = "Vocational degree") 
data$PEDU02 <- relevel(data$PEDU02, ref = "Vocational degree") 

# Define the event indicator (as a binary variables)
data$EVENT <- relevel(data$EVENT, ref = "No Birth") 
data$EVENT <- model.matrix(~data$EVENT)[,2]


Result <- PromotionTime.Bremhorst.et.al2016( 

    study.name = "Second birth", 
    n = dim(data)[1],
    obstime = data$END,
    Event = data$EVENT,  
    Cure = list(EDU02 = data$EDU02, PEDU02 = data$PEDU02, AGEKID1 = (data$AGEKID1C - 30), PERIOD = (data$PERIOD - 1998)), 
    Cox = list(EDU02 = data$EDU02, PEDU02 = data$PEDU02, AGEKID1 = (data$AGEKID1C - 30), PERIOD = (data$PERIOD - 1998)), 
    timeScale = "time (in month)", 
    hazard.profile = list(EDU02 = list("Voc degree", "no degree", "Uni (or FH) degree"), 
                          PEDU02 = list("Voc degree", "no degree", "Uni (or FH) degree")), 
    variables = c("Women educational level", "Partner educational level"),

    max_hazard = 0.08,
   
    post.probabilities = list(EDU02 = list("Voc degree", "no degree", "Uni (or FH) degree"),
                              PEDU02 = list("Voc degree", "no degree", "Uni (or FH) degree"))

    )

