##################################################################################################################
#
# Fertility progression in Gernamy : An application using non-parametric cure survival models
# Add here the reference!
#
# Code writen by V.Bremhorst (Universite catholique de Louvain - Belgium)
# Joint work with : * Michaela Kreyenfeld (Hertie School of Governance Berlin - Max Planck Insitute for 
#						 			      Demographic Research (Rostock)
#                   * Philippe Lambert (Universite de Liege and Universite catholique de Louvain (Beligum) 
#
# Contact : vincent.bremhorst@uclouvain.be  or vbremhorst@gmail.com 
#
#
#
#   *******************************************************************************************************
#   * Computation of the posterior probabilities of having the event for given covariate constellations.  *
#   *******************************************************************************************************
#
#
####################################################################################################################


posterior.probabilities <- function ( post.probabilities, 
                                      nbeta, 
                                      beta, 
                                      colnamesX, 
                                      newDirectory
                                    )
                             
{

   n.mod <- c() 
   cpt <- 1
   for( i in 1:length(post.probabilities)) {

      n.mod[i] <- length(post.probabilities[[i]]) 

   }
      
   prob.matrix <- matrix(NA, nrow = cumprod(n.mod)[length(n.mod)], ncol = 3) 
   colnames(prob.matrix) <- c("Q025", "Median", "Q975")      

   rnames <- c() 

   if (length(post.probabilities) == 1) {

      for(i in 1:length(post.probabilities[[1]])) {

         x_prob <- c(1, rep(0, nbeta-1))

         N1 <- paste( names(post.probabilities)[1], post.probabilities[[1]][i], sep = "-")
         index_N1 <- which(colnamesX == N1) 
         rnames[cpt] <- N1

         x_prob[c(index_N1)] <- 1 
       	 x_prob <- matrix(x_prob, nrow = 1) 

	 prob.matrix[cpt, ] <- quantile( 1 - exp( - exp( x_prob %*% beta ) ), c(0.025, 0.5, 0.975) )	
         cpt <- cpt + 1

      }

   }  
 
   else {

      for(i in 1:(length(post.probabilities)-1)) {

         for(j in (i+1):length(post.probabilities)) {

            for(k in 1:length(post.probabilities[[i]])) {
            
               N1 <- paste( names(post.probabilities)[i], post.probabilities[[i]][k], sep = "-")
               index_N1 <- which(colnamesX == N1) 
	 
               for(l in 1:length(post.probabilities[[j]])) {

                  x_prob <- c(1, rep(0, nbeta-1))

                  N2 <- paste( names(post.probabilities)[j], post.probabilities[[j]][l], sep = "-")
                  index_N2 <- which(colnamesX == N2) 
                  rnames[cpt] <- paste(N1, N2, sep = "**")

                  x_prob[c(index_N1, index_N2)] <- 1 
      	          x_prob <- matrix(x_prob, nrow = 1) 
                  prob.matrix[cpt, ] <- quantile( 1 - exp( - exp( x_prob %*% beta ) ), c(0.025, 0.5, 0.975) )	
                  cpt <- cpt + 1
               }  
 
            }

         }

      }

   }

   rownames(prob.matrix) <- rnames
   filename <- paste("probEvent", "txt", sep = ".")
   sink(paste(newDirectory, filename, sep = "/"))
   print( round(prob.matrix, 3))
   sink()
}

