##################################################################################################################
#
# Fertility progression in Gernamy : An application using non-parametric cure survival models
# Add here the reference!
#
# Code writen by V.Bremhorst (Universite catholique de Louvain - Belgium)
# Joint work with : * Michaela Kreyenfeld (Hertie School of Governance Berlin - Max Planck Insitute for 
#									      Demographic Research (Rostock)
#                   * Philippe Lambert (Universite de Liege and Universite catholique de Louvain (Beligum) 
#
# Contact : vincent.bremhorst@uclouvain.be  or vbremhorst@gmail.com 
#
#
#
#	     ****************************************************************************
#	     * Plot the trace of the posterior chains for all model parameters          *
#	     * Compute the Geweke convergence diagnostics for all model parameters      *
#            * (for both chains) 				                        *
#	     * Compute the Gelman-Rubin convergence diagnostic for all model parameters *
#	     ****************************************************************************
#
#
####################################################################################################################


Convergence.issues <- function( nbeta, 
                                beta, 
                                nlambda, 
                                lambda, 
                                nspline, 
                                phi, 
                                tau, 
                                delta, 
                                accept, 
	   		        newDirectory
                              ) 
{

   filename <- "acceptanceRate.txt" 
   sink(paste(newDirectory, filename, sep = "/")) 
   print( round(accept, 3) ) 
   sink() 


   filename <- paste("tau", "png", sep = ".") 
   png(file = paste(newDirectory, filename, sep = "/"))
   plot(tau[[1]], type = "l", col = "red", xlab = " iteration", ylab = " " , main = expression(tau))
   lines(tau[[2]], type = "l", col = "blue")
   dev.off()

   filename <- paste("delta", "png", sep = ".") 

   png(file = paste(newDirectory, filename, sep = "/"))
   plot(delta[[1]], type = "l", col = "red", ylab = "", xlab = "iteration", main = expression(delta))
   lines(delta[[2]], type = "l", col = "blue")
   dev.off()

   for(i in 1:nspline) {

      filename <- paste("phi", paste(i, "png", sep = "."), sep = "")  

      png(file = paste(newDirectory, filename, sep = "/"))
      plot(phi[[1]][i,], type = "l", col = "red", ylab = "", xlab = "iteration", main = paste("phi", i, sep = ""))
      lines(phi[[2]][i,], type = "l", col = "blue")
      dev.off()

   }    

   for(i in 1:nbeta) {

      filename <- paste("beta", paste(i-1, "png", sep = "."), sep = "")  

      png(file = paste(newDirectory, filename, sep = "/"))
      plot(beta[[1]][i,], type = "l", col = "red", ylab = "", xlab = "iteration", main = paste("beta", i-1, sep = ""))
      lines(beta[[2]][i,], type = "l", col = "blue")
      dev.off()

   }    

   for(i in 1:nlambda) {

      filename <- paste("lambda", paste(i, "png", sep = "."), sep = "")  
      png(file = paste(newDirectory, filename, sep = "/"))
      plot(lambda[[1]][i,], type = "l", col = "red", ylab = "", xlab = "iteration", main = paste("lambda", i, sep = ""))
      lines(lambda[[2]][i,], type = "l", col = "blue")
      dev.off()

   }    

   Geweke <- matrix(NA, ncol = 2, nrow = nspline+nbeta+nlambda+2)
   rownames(Geweke) <- c(paste("phi", 1:nspline, sep = ""), paste("beta", 1:(nbeta)-1, sep = ""), paste("lambda", 1:nlambda, sep = ""), "tau", "delta") 

   Geweke[,1] <- c( geweke.diag(t(phi[[1]]))$z[-(nspline+1)], 
                    geweke.diag(t(beta[[1]]))$z, 
                    geweke.diag(t(lambda[[1]]))$z,  
                    geweke.diag(tau[[1]])$z, 
                    geweke.diag(delta[[1]])$z)

   Geweke[,2] <- c( geweke.diag(t(phi[[2]]))$z[-(nspline+1)], 
                    geweke.diag(t(beta[[2]]))$z, 
                    geweke.diag(t(lambda[[2]]))$z,  
                    geweke.diag(tau[[2]])$z, 
                    geweke.diag(delta[[2]])$z)

   filename <- paste("Geweke", "txt", sep = ".") 

   sink(paste(newDirectory, filename, sep = "/"))
   print(round(Geweke,3))
   sink() 

   Gelman <- matrix(NA, ncol = 4, nrow = nspline + nbeta + nlambda+2)
   rownames(Gelman) <- c(paste("phi", 1:nspline, sep = ""), paste("beta", 1:(nbeta)-1, sep = ""), paste("lambda", 1:nlambda, sep = ""), "tau", "delta") 

   for(i in 1:(nspline)) {

      GEL <- mcmc.list(mcmc(phi[[1]][i,]), mcmc(phi[[2]][i,]))
      Gelman[i,1:2] <- gelman.diag(GEL, autoburnin = FALSE, multivariate = FALSE)$psrf 
      Gelman[i,3:4] <- gelman.diag(GEL, autoburnin = FALSE, multivariate = TRUE)$psrf 

   }    

   for(i in 1:nbeta) {

      GEL <- mcmc.list(mcmc(beta[[1]][i,]), mcmc(beta[[2]][i,]))
      Gelman[nspline+i,1:2] <- gelman.diag(GEL, autoburnin = FALSE, multivariate = FALSE)$psrf 
      Gelman[nspline+i,3:4] <- gelman.diag(GEL, autoburnin = FALSE, multivariate = TRUE)$psrf 

   }

   for(i in 1:nlambda) {

      GEL <- mcmc.list(mcmc(lambda[[1]][i,]), mcmc(lambda[[2]][i,]))
      Gelman[nspline+nbeta+i,1:2] <- gelman.diag(GEL, autoburnin = FALSE, multivariate = FALSE)$psrf 
      Gelman[nspline+nbeta+i,3:4] <- gelman.diag(GEL, autoburnin = FALSE, multivariate = TRUE)$psrf 

   }

   GEL <- mcmc.list(mcmc(tau[[1]]), mcmc(tau[[2]]))
   Gelman[dim(Gelman)[1]-1,1:2 ] <- gelman.diag(GEL, autoburnin = FALSE, multivariate = FALSE)$psrf
   Gelman[dim(Gelman)[1]-1,3:4 ] <- gelman.diag(GEL, autoburnin = FALSE, multivariate = TRUE)$psrf

   GEL <- mcmc.list(mcmc(delta[[1]]), mcmc(delta[[2]]))
   Gelman[dim(Gelman)[1], 1:2] <- gelman.diag(GEL, autoburnin = FALSE, multivariate = FALSE)$psrf
   Gelman[dim(Gelman)[1], 3:4] <- gelman.diag(GEL, autoburnin = FALSE, multivariate = TRUE)$psrf

   filename <- paste("Gelman", "txt", sep = ".") 

   sink(paste(newDirectory, filename, sep = "/"))
   print(round(Gelman,3))
   sink()
}

