##################################################################################################################
#
# Fertility progression in Gernamy : An application using non-parametric cure survival models
# Add here the reference!
#
# Code writen by V.Bremhorst (Universite catholique de Louvain - Belgium)
# Joint work with : * Michaela Kreyenfeld (Hertie School of Governance Berlin - Max Planck Insitute for 
#									      Demographic Research (Rostock)
#                   * Philippe Lambert (Universite de Liege and Universite catholique de Louvain (Beligum) 
#
# Contact : vincent.bremhorst@uclouvain.be  or vbremhorst@gmail.com 
#
#
#
#     ******************************************************************************************
#     * Computation of the population hazard function for a given covariates constellation     *
#     * (first component of the list)                                                          *
#     * Computation of the hazard function of the susceptible subjects for a given covariates  *
#     * constellation (second component of the list) 					       *
#     ******************************************************************************************
#
#
####################################################################################################################


hazard.functions <- function(X, beta, W, lambda, iteration, hazardEst, survivalEst) {

   theta <- exp( X %*% beta )
   Cov_exp <- exp(W %*% lambda) 

   hazard.latent    <- matrix(nrow = 200, ncol = iteration) 
   survival.latent  <- matrix(nrow = 200, ncol = iteration) 
   density.latent   <- matrix(nrow = 200, ncol = iteration) 
   pop.H            <- matrix(nrow = 200, ncol = iteration)
   pop.S            <- matrix(nrow = 200, ncol = iteration) 
   sucept.H         <- matrix(nrow = 200, ncol = iteration) 

   for(i in 1:200) {
   
      hazard.latent[i,] <- hazardEst[i,]*Cov_exp
      survival.latent[i,] <- survivalEst[i,]^Cov_exp
      density.latent[i,] <- hazard.latent[i,]*survival.latent[i,]

      pop.H[i,] <- theta*density.latent[i,]
      pop.S[i,] <- exp(-theta * ( 1-survival.latent[i,] ) ) 

      sucept.H[i,] <- ( pop.S[i,]*pop.H[i,] ) / ( pop.S[i,] - exp(-theta) )  

   }

   return(list(pop.H = pop.H, sucept.H = sucept.H))

}

