##################################################################################################################
#
# Fertility progression in Gernamy : An application using non-parametric cure survival models
# Add here the reference!
#
# Code writen by V.Bremhorst (Universite catholique de Louvain - Belgium)
# Joint work with : * Michaela Kreyenfeld (Hertie School of Governance Berlin - Max Planck Insitute for 
#						 			      Demographic Research (Rostock)
#                   * Philippe Lambert (Universite de Liege and Universite catholique de Louvain (Beligum) 
#
# Contact : vincent.bremhorst@uclouvain.be  or vbremhorst@gmail.com 
#
#
#
#     ******************************************************************************************
#     * plot of the population hazard function for given covariates constellations             *
#     * plot of the hazard function of the susceptible subjects for given covariate           *
#     * constellations 									       *
#     ******************************************************************************************
#
#
####################################################################################################################


PromotionTime.Graphs <- function(
                                newDirectory,
		                study.name,		
                		Q90, 
		      		xl, 
		     		xr,	
				max_hazard,			
                                hazardEst, 
				survivalEst, 
				Ref.pop, 	
			        Ref.suscept,
				hazard.profile, 
				variables,
				colnamesX,
				colnamesW,
                                beta, 
				nbeta, 
				lambda, 
				nlambda, 
				timeScale
                                )

{

   not_max_specify = FALSE 
   XX <- seq(xl, xr, length = 200)

   for(i in 1:length(hazard.profile)) {

      tools <- list() 

      for(j in 2:length(hazard.profile[[i]])) {   

         X <- c(1, rep(0, nbeta-1))    
         index <- which(colnamesX == paste( names(hazard.profile)[i], hazard.profile[[i]][j], sep = "-"))
         X[index] <- 1  
         X <- matrix(X, nrow = 1)       

         W <- rep(0, nlambda)
         index <- which(colnamesW == paste( names(hazard.profile)[i], hazard.profile[[i]][j], sep = "-"))    
         W[index] <- 1 
         W <- matrix(W, nrow = 1)

         temp <- hazard.functions( X=X, 
                                   beta=beta, 
                                   W=W, 
                                   lambda=lambda, 
                                   iteration=dim(survivalEst)[2], 
                                   hazardEst = hazardEst, 
				   survivalEst = survivalEst
                                   )

          tools[[2*(j-1)+1]] <- apply(temp[[1]], 1, median)[XX<Q90] 
	  tools[[2*j]] <- apply(temp[[2]], 1, median)[XX<Q90]

      }

      if(max_hazard == 0 | not_max_specify ) {
         
         max_hazard <- max(unlist(tools))
         not_max_specify = TRUE

      }

      filename <- paste(names(hazard.profile)[i], paste("PopHazard", "png", sep="."), sep = "-") 

      png(paste(newDirectory, filename, sep="/"))      
      par(mfrow = c(1,1), oma = c(0,0,2,0))

      plot(XX[XX<Q90], Ref.pop[XX<Q90], xaxt = "n", type = "l", xlim = c(0,max(XX[XX<Q90])), ylim = c(0, max_hazard), lty = 1, main = variables[i],  ylab = " ", xlab =timeScale, lwd = 2 ) 

#**************************
# !!! Modify if needed !!!
#**************************
      axis(1, seq(0, max(XX[XX<Q90]), by = 12), as.character(seq(0, max(XX[XX<Q90]), by = 12)), cex.axis = 0.75)  

      for(j in 2:length(hazard.profile[[i]])) {

         lines(XX[XX<Q90], tools[[2*(j-1)+1]], lty = j, lwd = 2) 
  
      }

      legend("topleft", unlist(hazard.profile[[i]]), lty = 1:3, lwd = rep(2, 3))
      mtext(paste(study.name, "Population hazard function", sep = " - "), cex = 1.5, side = 3, outer = TRUE)
      dev.off()
   

      filename <- paste(names(hazard.profile)[i], paste("SusceptHazard", "png", sep="."), sep = "-") 

      png(paste(newDirectory, filename, sep="/"))      
      par(mfrow = c(1,1), oma = c(0,0,2,0)) 

      plot(XX[XX<Q90], Ref.suscept[XX<Q90], xaxt = "n", type = "l", xlim = c(0,max(XX[XX<Q90])), ylim = c(0, max_hazard), lty = 1, main = variables[i], ylab = " ",xlab =timeScale, lwd = 2 ) 

#**************************
# !!! Modify if needed !!!
#**************************
      axis(1, seq(0, max(XX[XX<Q90]), by = 12), as.character(seq(0, max(XX[XX<Q90]), by = 12)), cex.axis = 0.75)  

      for(j in 2:length(hazard.profile[[i]])) {

         lines(XX[XX<Q90], tools[[2*j]], lty = j, lwd = 2) 
  
      }

      legend("topleft", unlist(hazard.profile[[i]]), lty = 1:3, lwd = rep(2, 3))
      mtext(paste(study.name, "Susceptible hazard function", sep = " - "), cex = 1.5, side = 3, outer = TRUE)
      dev.off()

   }    
   
}

