##################################################################################################################
#
# Fertility progression in Gernamy : An application using non-parametric cure survival models
# Add here the reference!
#
# Code writen by V.Bremhorst (Universite catholique de Louvain - Belgium)
# Joint work with : * Michaela Kreyenfeld (Hertie School of Governance Berlin - Max Planck Insitute for 
#						 			      Demographic Research (Rostock)
#                   * Philippe Lambert (Universite de Liege and Universite catholique de Louvain (Beligum) 
#
# Contact : vincent.bremhorst@uclouvain.be  or vbremhorst@gmail.com 
#
#
#
#	*********************************************************************
# 	* Computation of the logarithm of the joint posterior distribution. *
#	*********************************************************************
#
#
####################################################################################################################


log.post <- function(param,
                     Event,
                     nknots,
                     degree,
                     penalty,
                     nbeta,
                     nlambda,
                     Bmiddle,
                     Bobs,   
                     upto,
                     width,  
                     X, 
                     W, 
                     sd.Cov, 
                     atau, 
                     btau) { 

# Model parameters
    phi <- c(param[1:(nknots+degree-1)], 10)
    beta <- param[(nknots+degree-1+1):(nknots+degree-1+nbeta)]
    lambda <- param[(nknots+degree-1+nbeta+1):(nknots+degree-1+nbeta+nlambda)]
    tau <- exp(param[length(param)])

# Latent hazard function
    h <- exp((Bobs%*%phi))*exp(W%*%lambda)

# Latent cumulative hazard function
    temp <- exp((Bmiddle%*%phi))*width
    tempcum <- cumsum(temp) 
    Hcum <- tempcum[upto]
    Hcum <- Hcum*exp(W%*%lambda)

# Latent survival function
    S <- exp(-Hcum) 

# Latent density function
    f <- h*S

# Mean number of latent factors
    theta <- exp(X%*%beta)

# Contribution to the log likelihood
    t1 = sum(-theta* (1-S))
    t2 = sum(Event*log(theta))
    t3 = sum(Event*log(f))

# Prior distribution of the spline parameters
    t4 = (nknots+degree) * log(tau) / 2
    t5 = -tau * phi%*%penalty%*%phi / 2

# Prior distribution of the roughness penalty (for a fixed value of delta)
    t6 = (atau - 1) * log(tau)
    t7 = -btau * tau
   
# Prior distribution of the regression parameters (Cure & Cox)
    t8 = 0

    for(i in 1:nbeta) {
        t8 = t8 - beta[i]**2 / (2*sd.Cov**2)
    }

    for(i in 1:nlambda) {
        t8 = t8 - lambda[i]**2 / (2*sd.Cov**2)
    }

    return(-(t1+t2+t3+t4+t5+t6+t7+t8))

}

# Transformation of the log-posterior function into binary toolsbox
# ==> Speed the convergence time
log.post.c <- cmpfun(log.post)

