##################################################################################################################
#
# Fertility progression in Gernamy : An application using non-parametric cure survival models
# Add here the reference!
#
# Code writen by V.Bremhorst (Universite catholique de Louvain - Belgium)
# Joint work with : * Michaela Kreyenfeld (Hertie School of Governance Berlin - Max Planck Insitute for 
#						 			      Demographic Research (Rostock)
#                   * Philippe Lambert (Universite de Liege and Universite catholique de Louvain (Beligum) 
#
# Contact : vincent.bremhorst@uclouvain.be  or vbremhorst@gmail.com 
#
#
#
#	     *****************************************************************
#	     * Compute and return the numerical results of the analysis      *
#	     * Posterior median as estimator and the 90-95-99% HPD intervals *
#	     *****************************************************************
#
#
####################################################################################################################


Numerical.results <- function( nbeta,  
                              beta, 
                              colnamesX, 
                              nlambda,  
                              lambda, 
                              colnamesW, 
                              newDirectory
                            )
{


   betaHPD1 <- HPDinterval(mcmc(t(beta)), prob = 0.90)
   betaHPD2 <- HPDinterval(mcmc(t(beta)), prob = 0.95)
   betaHPD3 <- HPDinterval(mcmc(t(beta)), prob = 0.99)

   lambdaHPD1 <- HPDinterval(mcmc(t(lambda)), prob = 0.90)
   lambdaHPD2 <- HPDinterval(mcmc(t(lambda)), prob = 0.95)
   lambdaHPD3 <- HPDinterval(mcmc(t(lambda)), prob = 0.99)

   Cnames <- c("Estimation", "post sd", "Lower90", "Upper90", "Lower95",  "Upper95", "Lower99", "Upper99")
   result <- matrix(nrow = nbeta+nlambda, ncol = length(Cnames)) 
   dimnames(result) <- list(c(colnamesX, colnamesW), Cnames)

   result[,1] <- c(apply(beta, 1, median), apply(lambda, 1, median)) 
   result[,2] <- c(apply(beta, 1, sd), apply(lambda,1,sd)) 
   result[,3] <- c(betaHPD1[,1], lambdaHPD1[,1])
   result[,4] <- c(betaHPD1[,2], lambdaHPD1[,2])
   result[,5] <- c(betaHPD2[,1], lambdaHPD2[,1])
   result[,6] <- c(betaHPD2[,2], lambdaHPD2[,2])
   result[,7] <- c(betaHPD3[,1], lambdaHPD3[,1])
   result[,8] <- c(betaHPD3[,2], lambdaHPD3[,2])

   filename <- paste("NumericalResults", "txt", sep = ".") 

   sink(paste(newDirectory, filename, sep = "/"))
   print(round(result,3))
   sink()
   
   return(result)

}

